@@ -4,14 +4,14 @@
 #ifdef OPEN_ENCLAVE
 extern "C" const void* __oe_get_heap_base();
 extern "C" const void* __oe_get_heap_end();
-extern "C" void* oe_memset(void* p, int c, size_t size);
+extern "C" void* oe_memset_s(void* p, size_t p_size, int c, size_t size);
 extern "C" void oe_abort();
 
 namespace snmalloc
 {
   class PALOpenEnclave
   {
-    std::atomic<void*> oe_base;
+    std::atomic<void*> oe_base = nullptr;
 
   public:
     /**
@@ -54,7 +54,7 @@ namespace snmalloc
     template<bool page_aligned = false>
     void zero(void* p, size_t size) noexcept
     {
-      oe_memset(p, 0, size);
+      oe_memset_s(p, size, 0, size);
     }
   };
 }
